@@ -14,6 +14,7 @@ def test_nsum():
     assert nsum(lambda k: (-1)**k / log(k), [2, inf]).ae(0.9242998972229388)
     assert nsum(lambda k: 1/k**2, [1, inf]).ae(pi**2 / 6)
     assert nsum(lambda k: 2**k/fac(k), [0, inf]).ae(exp(2))
+    assert nsum(lambda k: 1/k**2, [4, inf], method='e').ae(0.2838229557371153)
 
 def test_nprod():
     mp.dps = 15
@@ -34,6 +35,15 @@ def test_fsum():
     assert fsum([2,1+1j,1]) == 4+1j
     assert fsum([1,mpi(2,3)]) == mpi(3,4)
     assert fsum([2,inf,3]) == inf
+    assert fsum([2,-1], absolute=1) == 3
+    assert fsum([2,-1], squared=1) == 5
+    assert fsum([1,1+j], squared=1) == 1+2j
+    assert fsum([1,3+4j], absolute=1) == 6
+    assert fsum([1,2+3j], absolute=1, squared=1) == 14
+    assert isnan(fsum([inf,-inf]))
+    assert fsum([inf,-inf], absolute=1) == inf
+    assert fsum([inf,-inf], squared=1) == inf
+    assert fsum([inf,-inf], absolute=1, squared=1) == inf
 
 def test_fprod():
     mp.dps = 15
